# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KubernetesClusterArgs', 'KubernetesCluster']

@pulumi.input_type
class KubernetesClusterArgs:
    def __init__(__self__, *,
                 cni: pulumi.Input[_builtins.str],
                 delete_additional_resources: pulumi.Input[_builtins.bool],
                 version: pulumi.Input[_builtins.str],
                 admission_plugins: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 apiserver_cert_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_upgrade: Optional[pulumi.Input['KubernetesClusterAutoUpgradeArgs']] = None,
                 autoscaler_config: Optional[pulumi.Input['KubernetesClusterAutoscalerConfigArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_gates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_id_connect_config: Optional[pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs']] = None,
                 pod_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 service_dns_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a KubernetesCluster resource.
        :param pulumi.Input[_builtins.str] cni: The Container Network Interface (CNI) for the Kubernetes cluster.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[_builtins.bool] delete_additional_resources: Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
               > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
               If you prefer keeping it, you should instead set it as `false`.
        :param pulumi.Input[_builtins.str] version: The version of the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admission_plugins: The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] apiserver_cert_sans: Additional Subject Alternative Names for the Kubernetes API server certificate
        :param pulumi.Input['KubernetesClusterAutoUpgradeArgs'] auto_upgrade: The auto upgrade configuration.
        :param pulumi.Input['KubernetesClusterAutoscalerConfigArgs'] autoscaler_config: The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        :param pulumi.Input[_builtins.str] description: A description for the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] feature_gates: The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        :param pulumi.Input[_builtins.str] name: The name for the Kubernetes cluster.
        :param pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs'] open_id_connect_config: The OpenID Connect configuration of the cluster
        :param pulumi.Input[_builtins.str] pod_cidr: The subnet used for the Pod CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network of the cluster.
               
               > **Important:** Changes to this field will recreate a new resource.
               
               > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
               you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] service_cidr: The subnet used for the Service CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] service_dns_ip: The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Kubernetes cluster.
        :param pulumi.Input[_builtins.str] type: The type of Kubernetes cluster. Possible values are:
               
               - for mutualized clusters: `kapsule` or `multicloud`
               
               - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.
               
               - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        """
        pulumi.set(__self__, "cni", cni)
        pulumi.set(__self__, "delete_additional_resources", delete_additional_resources)
        pulumi.set(__self__, "version", version)
        if admission_plugins is not None:
            pulumi.set(__self__, "admission_plugins", admission_plugins)
        if apiserver_cert_sans is not None:
            pulumi.set(__self__, "apiserver_cert_sans", apiserver_cert_sans)
        if auto_upgrade is not None:
            pulumi.set(__self__, "auto_upgrade", auto_upgrade)
        if autoscaler_config is not None:
            pulumi.set(__self__, "autoscaler_config", autoscaler_config)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if feature_gates is not None:
            pulumi.set(__self__, "feature_gates", feature_gates)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if open_id_connect_config is not None:
            pulumi.set(__self__, "open_id_connect_config", open_id_connect_config)
        if pod_cidr is not None:
            pulumi.set(__self__, "pod_cidr", pod_cidr)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_cidr is not None:
            pulumi.set(__self__, "service_cidr", service_cidr)
        if service_dns_ip is not None:
            pulumi.set(__self__, "service_dns_ip", service_dns_ip)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def cni(self) -> pulumi.Input[_builtins.str]:
        """
        The Container Network Interface (CNI) for the Kubernetes cluster.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "cni")

    @cni.setter
    def cni(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cni", value)

    @_builtins.property
    @pulumi.getter(name="deleteAdditionalResources")
    def delete_additional_resources(self) -> pulumi.Input[_builtins.bool]:
        """
        Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
        > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
        If you prefer keeping it, you should instead set it as `false`.
        """
        return pulumi.get(self, "delete_additional_resources")

    @delete_additional_resources.setter
    def delete_additional_resources(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "delete_additional_resources", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Input[_builtins.str]:
        """
        The version of the Kubernetes cluster.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="admissionPlugins")
    def admission_plugins(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        """
        return pulumi.get(self, "admission_plugins")

    @admission_plugins.setter
    def admission_plugins(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "admission_plugins", value)

    @_builtins.property
    @pulumi.getter(name="apiserverCertSans")
    def apiserver_cert_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Additional Subject Alternative Names for the Kubernetes API server certificate
        """
        return pulumi.get(self, "apiserver_cert_sans")

    @apiserver_cert_sans.setter
    def apiserver_cert_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "apiserver_cert_sans", value)

    @_builtins.property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> Optional[pulumi.Input['KubernetesClusterAutoUpgradeArgs']]:
        """
        The auto upgrade configuration.
        """
        return pulumi.get(self, "auto_upgrade")

    @auto_upgrade.setter
    def auto_upgrade(self, value: Optional[pulumi.Input['KubernetesClusterAutoUpgradeArgs']]):
        pulumi.set(self, "auto_upgrade", value)

    @_builtins.property
    @pulumi.getter(name="autoscalerConfig")
    def autoscaler_config(self) -> Optional[pulumi.Input['KubernetesClusterAutoscalerConfigArgs']]:
        """
        The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        """
        return pulumi.get(self, "autoscaler_config")

    @autoscaler_config.setter
    def autoscaler_config(self, value: Optional[pulumi.Input['KubernetesClusterAutoscalerConfigArgs']]):
        pulumi.set(self, "autoscaler_config", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description for the Kubernetes cluster.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="featureGates")
    def feature_gates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        """
        return pulumi.get(self, "feature_gates")

    @feature_gates.setter
    def feature_gates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "feature_gates", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the Kubernetes cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="openIdConnectConfig")
    def open_id_connect_config(self) -> Optional[pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs']]:
        """
        The OpenID Connect configuration of the cluster
        """
        return pulumi.get(self, "open_id_connect_config")

    @open_id_connect_config.setter
    def open_id_connect_config(self, value: Optional[pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs']]):
        pulumi.set(self, "open_id_connect_config", value)

    @_builtins.property
    @pulumi.getter(name="podCidr")
    def pod_cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subnet used for the Pod CIDR.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "pod_cidr")

    @pod_cidr.setter
    def pod_cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pod_cidr", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the private network of the cluster.

        > **Important:** Changes to this field will recreate a new resource.

        > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
        you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceCidr")
    def service_cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subnet used for the Service CIDR.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "service_cidr")

    @service_cidr.setter
    def service_cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_cidr", value)

    @_builtins.property
    @pulumi.getter(name="serviceDnsIp")
    def service_dns_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "service_dns_ip")

    @service_dns_ip.setter
    def service_dns_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_dns_ip", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the Kubernetes cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of Kubernetes cluster. Possible values are:

        - for mutualized clusters: `kapsule` or `multicloud`

        - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.

        - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _KubernetesClusterState:
    def __init__(__self__, *,
                 admission_plugins: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 apiserver_cert_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 apiserver_url: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_upgrade: Optional[pulumi.Input['KubernetesClusterAutoUpgradeArgs']] = None,
                 autoscaler_config: Optional[pulumi.Input['KubernetesClusterAutoscalerConfigArgs']] = None,
                 cni: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_additional_resources: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_gates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 kubeconfigs: Optional[pulumi.Input[Sequence[pulumi.Input['KubernetesClusterKubeconfigArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_id_connect_config: Optional[pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs']] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pod_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 service_dns_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 upgrade_available: Optional[pulumi.Input[_builtins.bool]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 wildcard_dns: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering KubernetesCluster resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admission_plugins: The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] apiserver_cert_sans: Additional Subject Alternative Names for the Kubernetes API server certificate
        :param pulumi.Input[_builtins.str] apiserver_url: The URL of the Kubernetes API server.
        :param pulumi.Input['KubernetesClusterAutoUpgradeArgs'] auto_upgrade: The auto upgrade configuration.
        :param pulumi.Input['KubernetesClusterAutoscalerConfigArgs'] autoscaler_config: The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        :param pulumi.Input[_builtins.str] cni: The Container Network Interface (CNI) for the Kubernetes cluster.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[_builtins.str] created_at: The creation date of the cluster.
        :param pulumi.Input[_builtins.bool] delete_additional_resources: Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
               > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
               If you prefer keeping it, you should instead set it as `false`.
        :param pulumi.Input[_builtins.str] description: A description for the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] feature_gates: The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        :param pulumi.Input[Sequence[pulumi.Input['KubernetesClusterKubeconfigArgs']]] kubeconfigs: The kubeconfig configuration file of the Kubernetes cluster
        :param pulumi.Input[_builtins.str] name: The name for the Kubernetes cluster.
        :param pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs'] open_id_connect_config: The OpenID Connect configuration of the cluster
        :param pulumi.Input[_builtins.str] organization_id: The organization ID the cluster is associated with.
        :param pulumi.Input[_builtins.str] pod_cidr: The subnet used for the Pod CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network of the cluster.
               
               > **Important:** Changes to this field will recreate a new resource.
               
               > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
               you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] service_cidr: The subnet used for the Service CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] service_dns_ip: The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] status: The status of the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Kubernetes cluster.
        :param pulumi.Input[_builtins.str] type: The type of Kubernetes cluster. Possible values are:
               
               - for mutualized clusters: `kapsule` or `multicloud`
               
               - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.
               
               - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        :param pulumi.Input[_builtins.str] updated_at: The last update date of the cluster.
        :param pulumi.Input[_builtins.bool] upgrade_available: Set to `true` if a newer Kubernetes version is available.
        :param pulumi.Input[_builtins.str] version: The version of the Kubernetes cluster.
        :param pulumi.Input[_builtins.str] wildcard_dns: The DNS wildcard that points to all ready nodes.
        """
        if admission_plugins is not None:
            pulumi.set(__self__, "admission_plugins", admission_plugins)
        if apiserver_cert_sans is not None:
            pulumi.set(__self__, "apiserver_cert_sans", apiserver_cert_sans)
        if apiserver_url is not None:
            pulumi.set(__self__, "apiserver_url", apiserver_url)
        if auto_upgrade is not None:
            pulumi.set(__self__, "auto_upgrade", auto_upgrade)
        if autoscaler_config is not None:
            pulumi.set(__self__, "autoscaler_config", autoscaler_config)
        if cni is not None:
            pulumi.set(__self__, "cni", cni)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if delete_additional_resources is not None:
            pulumi.set(__self__, "delete_additional_resources", delete_additional_resources)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if feature_gates is not None:
            pulumi.set(__self__, "feature_gates", feature_gates)
        if kubeconfigs is not None:
            pulumi.set(__self__, "kubeconfigs", kubeconfigs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if open_id_connect_config is not None:
            pulumi.set(__self__, "open_id_connect_config", open_id_connect_config)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if pod_cidr is not None:
            pulumi.set(__self__, "pod_cidr", pod_cidr)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_cidr is not None:
            pulumi.set(__self__, "service_cidr", service_cidr)
        if service_dns_ip is not None:
            pulumi.set(__self__, "service_dns_ip", service_dns_ip)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if upgrade_available is not None:
            pulumi.set(__self__, "upgrade_available", upgrade_available)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if wildcard_dns is not None:
            pulumi.set(__self__, "wildcard_dns", wildcard_dns)

    @_builtins.property
    @pulumi.getter(name="admissionPlugins")
    def admission_plugins(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        """
        return pulumi.get(self, "admission_plugins")

    @admission_plugins.setter
    def admission_plugins(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "admission_plugins", value)

    @_builtins.property
    @pulumi.getter(name="apiserverCertSans")
    def apiserver_cert_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Additional Subject Alternative Names for the Kubernetes API server certificate
        """
        return pulumi.get(self, "apiserver_cert_sans")

    @apiserver_cert_sans.setter
    def apiserver_cert_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "apiserver_cert_sans", value)

    @_builtins.property
    @pulumi.getter(name="apiserverUrl")
    def apiserver_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the Kubernetes API server.
        """
        return pulumi.get(self, "apiserver_url")

    @apiserver_url.setter
    def apiserver_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "apiserver_url", value)

    @_builtins.property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> Optional[pulumi.Input['KubernetesClusterAutoUpgradeArgs']]:
        """
        The auto upgrade configuration.
        """
        return pulumi.get(self, "auto_upgrade")

    @auto_upgrade.setter
    def auto_upgrade(self, value: Optional[pulumi.Input['KubernetesClusterAutoUpgradeArgs']]):
        pulumi.set(self, "auto_upgrade", value)

    @_builtins.property
    @pulumi.getter(name="autoscalerConfig")
    def autoscaler_config(self) -> Optional[pulumi.Input['KubernetesClusterAutoscalerConfigArgs']]:
        """
        The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        """
        return pulumi.get(self, "autoscaler_config")

    @autoscaler_config.setter
    def autoscaler_config(self, value: Optional[pulumi.Input['KubernetesClusterAutoscalerConfigArgs']]):
        pulumi.set(self, "autoscaler_config", value)

    @_builtins.property
    @pulumi.getter
    def cni(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Container Network Interface (CNI) for the Kubernetes cluster.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "cni")

    @cni.setter
    def cni(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cni", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The creation date of the cluster.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="deleteAdditionalResources")
    def delete_additional_resources(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
        > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
        If you prefer keeping it, you should instead set it as `false`.
        """
        return pulumi.get(self, "delete_additional_resources")

    @delete_additional_resources.setter
    def delete_additional_resources(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_additional_resources", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description for the Kubernetes cluster.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="featureGates")
    def feature_gates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        """
        return pulumi.get(self, "feature_gates")

    @feature_gates.setter
    def feature_gates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "feature_gates", value)

    @_builtins.property
    @pulumi.getter
    def kubeconfigs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubernetesClusterKubeconfigArgs']]]]:
        """
        The kubeconfig configuration file of the Kubernetes cluster
        """
        return pulumi.get(self, "kubeconfigs")

    @kubeconfigs.setter
    def kubeconfigs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubernetesClusterKubeconfigArgs']]]]):
        pulumi.set(self, "kubeconfigs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the Kubernetes cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="openIdConnectConfig")
    def open_id_connect_config(self) -> Optional[pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs']]:
        """
        The OpenID Connect configuration of the cluster
        """
        return pulumi.get(self, "open_id_connect_config")

    @open_id_connect_config.setter
    def open_id_connect_config(self, value: Optional[pulumi.Input['KubernetesClusterOpenIdConnectConfigArgs']]):
        pulumi.set(self, "open_id_connect_config", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID the cluster is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="podCidr")
    def pod_cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subnet used for the Pod CIDR.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "pod_cidr")

    @pod_cidr.setter
    def pod_cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pod_cidr", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the private network of the cluster.

        > **Important:** Changes to this field will recreate a new resource.

        > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
        you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceCidr")
    def service_cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subnet used for the Service CIDR.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "service_cidr")

    @service_cidr.setter
    def service_cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_cidr", value)

    @_builtins.property
    @pulumi.getter(name="serviceDnsIp")
    def service_dns_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "service_dns_ip")

    @service_dns_ip.setter
    def service_dns_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_dns_ip", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the Kubernetes cluster.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the Kubernetes cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of Kubernetes cluster. Possible values are:

        - for mutualized clusters: `kapsule` or `multicloud`

        - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.

        - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last update date of the cluster.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="upgradeAvailable")
    def upgrade_available(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to `true` if a newer Kubernetes version is available.
        """
        return pulumi.get(self, "upgrade_available")

    @upgrade_available.setter
    def upgrade_available(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upgrade_available", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The version of the Kubernetes cluster.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="wildcardDns")
    def wildcard_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The DNS wildcard that points to all ready nodes.
        """
        return pulumi.get(self, "wildcard_dns")

    @wildcard_dns.setter
    def wildcard_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "wildcard_dns", value)


warnings.warn("""scaleway.index/kubernetescluster.KubernetesCluster has been deprecated in favor of scaleway.kubernetes/cluster.Cluster""", DeprecationWarning)


@pulumi.type_token("scaleway:index/kubernetesCluster:KubernetesCluster")
class KubernetesCluster(pulumi.CustomResource):
    warnings.warn("""scaleway.index/kubernetescluster.KubernetesCluster has been deprecated in favor of scaleway.kubernetes/cluster.Cluster""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admission_plugins: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 apiserver_cert_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_upgrade: Optional[pulumi.Input[Union['KubernetesClusterAutoUpgradeArgs', 'KubernetesClusterAutoUpgradeArgsDict']]] = None,
                 autoscaler_config: Optional[pulumi.Input[Union['KubernetesClusterAutoscalerConfigArgs', 'KubernetesClusterAutoscalerConfigArgsDict']]] = None,
                 cni: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_additional_resources: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_gates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_id_connect_config: Optional[pulumi.Input[Union['KubernetesClusterOpenIdConnectConfigArgs', 'KubernetesClusterOpenIdConnectConfigArgsDict']]] = None,
                 pod_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 service_dns_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `kubernetes.Cluster` resource allows you to create and manage Scaleway Kubernetes clusters.

        Refer to the Kubernetes [documentation](https://www.scaleway.com/en/docs/compute/kubernetes/) and [API documentation](https://www.scaleway.com/en/developers/api/kubernetes/) for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.32.3",
            cni="cilium",
            private_network_id=pn.id,
            delete_additional_resources=False)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=1)
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            description="cluster made in terraform",
            version="1.32.3",
            cni="calico",
            tags=["terraform"],
            private_network_id=pn.id,
            delete_additional_resources=False,
            autoscaler_config={
                "disable_scale_down": False,
                "scale_down_delay_after_add": "5m",
                "estimator": "binpacking",
                "expander": "random",
                "ignore_daemonsets_utilization": True,
                "balance_similar_node_groups": True,
                "expendable_pods_priority_cutoff": -5,
            })
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=3,
            autoscaling=True,
            autohealing=True,
            min_size=1,
            max_size=5)
        ```

        ```python
        import pulumi
        import pulumi_helm as helm
        import pulumi_null as null
        import pulumiverse_scaleway as scaleway

        # Example with an Helm provider
        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.29.1",
            cni="cilium",
            delete_additional_resources=False,
            private_network_id=pn.id)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=1)
        kubeconfig = null.Resource("kubeconfig", triggers={
            "host": cluster.kubeconfigs[0].host,
            "token": cluster.kubeconfigs[0].token,
            "clusterCaCertificate": cluster.kubeconfigs[0].cluster_ca_certificate,
        },
        opts = pulumi.ResourceOptions(depends_on=[pool]))
        nginx_ip = scaleway.loadbalancers.Ip("nginx_ip",
            zone="fr-par-1",
            project_id=cluster.project_id)
        nginx_ingress = helm.index.Release("nginx_ingress",
            name=nginx-ingress,
            namespace=kube-system,
            repository=https://kubernetes.github.io/ingress-nginx,
            chart=ingress-nginx,
            set=[
                {
                    name: controller.service.loadBalancerIP,
                    value: nginx_ip.ip_address,
                },
                {
                    name: controller.config.use-proxy-protocol,
                    value: true,
                },
                {
                    name: controller.service.annotations.service\\.beta\\.kubernetes\\.io/scw-loadbalancer-proxy-protocol-v2,
                    value: true,
                },
                {
                    name: controller.service.annotations.service\\.beta\\.kubernetes\\.io/scw-loadbalancer-zone,
                    value: nginx_ip.zone,
                },
                {
                    name: controller.service.externalTrafficPolicy,
                    value: Local,
                },
            ])
        ```

        ```python
        import pulumi
        import pulumi_null as null
        import pulumiverse_scaleway as scaleway

        # Example with the kubernetes provider 
        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.29.1",
            cni="cilium",
            private_network_id=pn.id,
            delete_additional_resources=False)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=1)
        # The `null_resource` is needed because when the cluster is created, its status is `pool_required`, but the kubeconfig can already be downloaded.
        # It leads the `kubernetes` provider to start creating its objects, but the DNS entry for the Kubernetes master is not yet ready, that's why it's needed to wait for at least a pool.
        kubeconfig = null.Resource("kubeconfig", triggers={
            "host": cluster.kubeconfigs[0].host,
            "token": cluster.kubeconfigs[0].token,
            "clusterCaCertificate": cluster.kubeconfigs[0].cluster_ca_certificate,
        },
        opts = pulumi.ResourceOptions(depends_on=[pool]))
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # Multicloud Kubernetes Cluster Example
        # For a detailed example of how to add or run Elastic Metal servers instead of Instances on your cluster, please refer to [this guide](../guides/multicloud_cluster_with_baremetal_servers.md).
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            type="multicloud",
            version="1.32.3",
            cni="kilo",
            delete_additional_resources=False)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="external",
            size=0,
            min_size=0)
        ```

        ## Deprecation of default_pool

        `default_pool` is deprecated in favour the `kubernetes.Pool` resource. Here is a migration example.

        Before:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.18.0",
            cni="cilium",
            default_pool=[{
                "nodeType": "DEV1-M",
                "size": 1,
            }])
        ```

        After:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.18.0",
            cni="cilium")
        default = scaleway.kubernetes.Pool("default",
            cluster_id=jack["id"],
            name="default",
            node_type="DEV1-M",
            size=1)
        ```

        Once you have moved all the `default_pool` into their own object, you will need to import them. If your pool had the ID 11111111-1111-1111-1111-111111111111 in the `fr-par` region, you can import it by typing:

        Then you will only need to type `pulumi up` to have a smooth migration.

        ## Import

        Kubernetes clusters can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/kubernetesCluster:KubernetesCluster mycluster fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admission_plugins: The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] apiserver_cert_sans: Additional Subject Alternative Names for the Kubernetes API server certificate
        :param pulumi.Input[Union['KubernetesClusterAutoUpgradeArgs', 'KubernetesClusterAutoUpgradeArgsDict']] auto_upgrade: The auto upgrade configuration.
        :param pulumi.Input[Union['KubernetesClusterAutoscalerConfigArgs', 'KubernetesClusterAutoscalerConfigArgsDict']] autoscaler_config: The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        :param pulumi.Input[_builtins.str] cni: The Container Network Interface (CNI) for the Kubernetes cluster.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[_builtins.bool] delete_additional_resources: Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
               > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
               If you prefer keeping it, you should instead set it as `false`.
        :param pulumi.Input[_builtins.str] description: A description for the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] feature_gates: The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        :param pulumi.Input[_builtins.str] name: The name for the Kubernetes cluster.
        :param pulumi.Input[Union['KubernetesClusterOpenIdConnectConfigArgs', 'KubernetesClusterOpenIdConnectConfigArgsDict']] open_id_connect_config: The OpenID Connect configuration of the cluster
        :param pulumi.Input[_builtins.str] pod_cidr: The subnet used for the Pod CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network of the cluster.
               
               > **Important:** Changes to this field will recreate a new resource.
               
               > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
               you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] service_cidr: The subnet used for the Service CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] service_dns_ip: The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Kubernetes cluster.
        :param pulumi.Input[_builtins.str] type: The type of Kubernetes cluster. Possible values are:
               
               - for mutualized clusters: `kapsule` or `multicloud`
               
               - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.
               
               - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        :param pulumi.Input[_builtins.str] version: The version of the Kubernetes cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubernetesClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `kubernetes.Cluster` resource allows you to create and manage Scaleway Kubernetes clusters.

        Refer to the Kubernetes [documentation](https://www.scaleway.com/en/docs/compute/kubernetes/) and [API documentation](https://www.scaleway.com/en/developers/api/kubernetes/) for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.32.3",
            cni="cilium",
            private_network_id=pn.id,
            delete_additional_resources=False)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=1)
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            description="cluster made in terraform",
            version="1.32.3",
            cni="calico",
            tags=["terraform"],
            private_network_id=pn.id,
            delete_additional_resources=False,
            autoscaler_config={
                "disable_scale_down": False,
                "scale_down_delay_after_add": "5m",
                "estimator": "binpacking",
                "expander": "random",
                "ignore_daemonsets_utilization": True,
                "balance_similar_node_groups": True,
                "expendable_pods_priority_cutoff": -5,
            })
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=3,
            autoscaling=True,
            autohealing=True,
            min_size=1,
            max_size=5)
        ```

        ```python
        import pulumi
        import pulumi_helm as helm
        import pulumi_null as null
        import pulumiverse_scaleway as scaleway

        # Example with an Helm provider
        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.29.1",
            cni="cilium",
            delete_additional_resources=False,
            private_network_id=pn.id)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=1)
        kubeconfig = null.Resource("kubeconfig", triggers={
            "host": cluster.kubeconfigs[0].host,
            "token": cluster.kubeconfigs[0].token,
            "clusterCaCertificate": cluster.kubeconfigs[0].cluster_ca_certificate,
        },
        opts = pulumi.ResourceOptions(depends_on=[pool]))
        nginx_ip = scaleway.loadbalancers.Ip("nginx_ip",
            zone="fr-par-1",
            project_id=cluster.project_id)
        nginx_ingress = helm.index.Release("nginx_ingress",
            name=nginx-ingress,
            namespace=kube-system,
            repository=https://kubernetes.github.io/ingress-nginx,
            chart=ingress-nginx,
            set=[
                {
                    name: controller.service.loadBalancerIP,
                    value: nginx_ip.ip_address,
                },
                {
                    name: controller.config.use-proxy-protocol,
                    value: true,
                },
                {
                    name: controller.service.annotations.service\\.beta\\.kubernetes\\.io/scw-loadbalancer-proxy-protocol-v2,
                    value: true,
                },
                {
                    name: controller.service.annotations.service\\.beta\\.kubernetes\\.io/scw-loadbalancer-zone,
                    value: nginx_ip.zone,
                },
                {
                    name: controller.service.externalTrafficPolicy,
                    value: Local,
                },
            ])
        ```

        ```python
        import pulumi
        import pulumi_null as null
        import pulumiverse_scaleway as scaleway

        # Example with the kubernetes provider 
        pn = scaleway.network.PrivateNetwork("pn")
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.29.1",
            cni="cilium",
            private_network_id=pn.id,
            delete_additional_resources=False)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="DEV1-M",
            size=1)
        # The `null_resource` is needed because when the cluster is created, its status is `pool_required`, but the kubeconfig can already be downloaded.
        # It leads the `kubernetes` provider to start creating its objects, but the DNS entry for the Kubernetes master is not yet ready, that's why it's needed to wait for at least a pool.
        kubeconfig = null.Resource("kubeconfig", triggers={
            "host": cluster.kubeconfigs[0].host,
            "token": cluster.kubeconfigs[0].token,
            "clusterCaCertificate": cluster.kubeconfigs[0].cluster_ca_certificate,
        },
        opts = pulumi.ResourceOptions(depends_on=[pool]))
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # Multicloud Kubernetes Cluster Example
        # For a detailed example of how to add or run Elastic Metal servers instead of Instances on your cluster, please refer to [this guide](../guides/multicloud_cluster_with_baremetal_servers.md).
        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            type="multicloud",
            version="1.32.3",
            cni="kilo",
            delete_additional_resources=False)
        pool = scaleway.kubernetes.Pool("pool",
            cluster_id=cluster.id,
            name="tf-pool",
            node_type="external",
            size=0,
            min_size=0)
        ```

        ## Deprecation of default_pool

        `default_pool` is deprecated in favour the `kubernetes.Pool` resource. Here is a migration example.

        Before:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.18.0",
            cni="cilium",
            default_pool=[{
                "nodeType": "DEV1-M",
                "size": 1,
            }])
        ```

        After:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        cluster = scaleway.kubernetes.Cluster("cluster",
            name="tf-cluster",
            version="1.18.0",
            cni="cilium")
        default = scaleway.kubernetes.Pool("default",
            cluster_id=jack["id"],
            name="default",
            node_type="DEV1-M",
            size=1)
        ```

        Once you have moved all the `default_pool` into their own object, you will need to import them. If your pool had the ID 11111111-1111-1111-1111-111111111111 in the `fr-par` region, you can import it by typing:

        Then you will only need to type `pulumi up` to have a smooth migration.

        ## Import

        Kubernetes clusters can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/kubernetesCluster:KubernetesCluster mycluster fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param KubernetesClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubernetesClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admission_plugins: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 apiserver_cert_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_upgrade: Optional[pulumi.Input[Union['KubernetesClusterAutoUpgradeArgs', 'KubernetesClusterAutoUpgradeArgsDict']]] = None,
                 autoscaler_config: Optional[pulumi.Input[Union['KubernetesClusterAutoscalerConfigArgs', 'KubernetesClusterAutoscalerConfigArgsDict']]] = None,
                 cni: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_additional_resources: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_gates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_id_connect_config: Optional[pulumi.Input[Union['KubernetesClusterOpenIdConnectConfigArgs', 'KubernetesClusterOpenIdConnectConfigArgsDict']]] = None,
                 pod_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 service_dns_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""KubernetesCluster is deprecated: scaleway.index/kubernetescluster.KubernetesCluster has been deprecated in favor of scaleway.kubernetes/cluster.Cluster""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubernetesClusterArgs.__new__(KubernetesClusterArgs)

            __props__.__dict__["admission_plugins"] = admission_plugins
            __props__.__dict__["apiserver_cert_sans"] = apiserver_cert_sans
            __props__.__dict__["auto_upgrade"] = auto_upgrade
            __props__.__dict__["autoscaler_config"] = autoscaler_config
            if cni is None and not opts.urn:
                raise TypeError("Missing required property 'cni'")
            __props__.__dict__["cni"] = cni
            if delete_additional_resources is None and not opts.urn:
                raise TypeError("Missing required property 'delete_additional_resources'")
            __props__.__dict__["delete_additional_resources"] = delete_additional_resources
            __props__.__dict__["description"] = description
            __props__.__dict__["feature_gates"] = feature_gates
            __props__.__dict__["name"] = name
            __props__.__dict__["open_id_connect_config"] = open_id_connect_config
            __props__.__dict__["pod_cidr"] = pod_cidr
            __props__.__dict__["private_network_id"] = private_network_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["service_cidr"] = service_cidr
            __props__.__dict__["service_dns_ip"] = service_dns_ip
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            __props__.__dict__["apiserver_url"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["kubeconfigs"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["upgrade_available"] = None
            __props__.__dict__["wildcard_dns"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["kubeconfigs"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(KubernetesCluster, __self__).__init__(
            'scaleway:index/kubernetesCluster:KubernetesCluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            admission_plugins: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            apiserver_cert_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            apiserver_url: Optional[pulumi.Input[_builtins.str]] = None,
            auto_upgrade: Optional[pulumi.Input[Union['KubernetesClusterAutoUpgradeArgs', 'KubernetesClusterAutoUpgradeArgsDict']]] = None,
            autoscaler_config: Optional[pulumi.Input[Union['KubernetesClusterAutoscalerConfigArgs', 'KubernetesClusterAutoscalerConfigArgsDict']]] = None,
            cni: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            delete_additional_resources: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            feature_gates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            kubeconfigs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubernetesClusterKubeconfigArgs', 'KubernetesClusterKubeconfigArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            open_id_connect_config: Optional[pulumi.Input[Union['KubernetesClusterOpenIdConnectConfigArgs', 'KubernetesClusterOpenIdConnectConfigArgsDict']]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            pod_cidr: Optional[pulumi.Input[_builtins.str]] = None,
            private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            service_cidr: Optional[pulumi.Input[_builtins.str]] = None,
            service_dns_ip: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            upgrade_available: Optional[pulumi.Input[_builtins.bool]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None,
            wildcard_dns: Optional[pulumi.Input[_builtins.str]] = None) -> 'KubernetesCluster':
        """
        Get an existing KubernetesCluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admission_plugins: The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] apiserver_cert_sans: Additional Subject Alternative Names for the Kubernetes API server certificate
        :param pulumi.Input[_builtins.str] apiserver_url: The URL of the Kubernetes API server.
        :param pulumi.Input[Union['KubernetesClusterAutoUpgradeArgs', 'KubernetesClusterAutoUpgradeArgsDict']] auto_upgrade: The auto upgrade configuration.
        :param pulumi.Input[Union['KubernetesClusterAutoscalerConfigArgs', 'KubernetesClusterAutoscalerConfigArgsDict']] autoscaler_config: The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        :param pulumi.Input[_builtins.str] cni: The Container Network Interface (CNI) for the Kubernetes cluster.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[_builtins.str] created_at: The creation date of the cluster.
        :param pulumi.Input[_builtins.bool] delete_additional_resources: Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
               > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
               If you prefer keeping it, you should instead set it as `false`.
        :param pulumi.Input[_builtins.str] description: A description for the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] feature_gates: The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['KubernetesClusterKubeconfigArgs', 'KubernetesClusterKubeconfigArgsDict']]]] kubeconfigs: The kubeconfig configuration file of the Kubernetes cluster
        :param pulumi.Input[_builtins.str] name: The name for the Kubernetes cluster.
        :param pulumi.Input[Union['KubernetesClusterOpenIdConnectConfigArgs', 'KubernetesClusterOpenIdConnectConfigArgsDict']] open_id_connect_config: The OpenID Connect configuration of the cluster
        :param pulumi.Input[_builtins.str] organization_id: The organization ID the cluster is associated with.
        :param pulumi.Input[_builtins.str] pod_cidr: The subnet used for the Pod CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network of the cluster.
               
               > **Important:** Changes to this field will recreate a new resource.
               
               > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
               you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] service_cidr: The subnet used for the Service CIDR.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] service_dns_ip: The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.
               
               > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
               unsetting it to go back to the default value will not have any effect.
        :param pulumi.Input[_builtins.str] status: The status of the Kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Kubernetes cluster.
        :param pulumi.Input[_builtins.str] type: The type of Kubernetes cluster. Possible values are:
               
               - for mutualized clusters: `kapsule` or `multicloud`
               
               - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.
               
               - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        :param pulumi.Input[_builtins.str] updated_at: The last update date of the cluster.
        :param pulumi.Input[_builtins.bool] upgrade_available: Set to `true` if a newer Kubernetes version is available.
        :param pulumi.Input[_builtins.str] version: The version of the Kubernetes cluster.
        :param pulumi.Input[_builtins.str] wildcard_dns: The DNS wildcard that points to all ready nodes.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KubernetesClusterState.__new__(_KubernetesClusterState)

        __props__.__dict__["admission_plugins"] = admission_plugins
        __props__.__dict__["apiserver_cert_sans"] = apiserver_cert_sans
        __props__.__dict__["apiserver_url"] = apiserver_url
        __props__.__dict__["auto_upgrade"] = auto_upgrade
        __props__.__dict__["autoscaler_config"] = autoscaler_config
        __props__.__dict__["cni"] = cni
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["delete_additional_resources"] = delete_additional_resources
        __props__.__dict__["description"] = description
        __props__.__dict__["feature_gates"] = feature_gates
        __props__.__dict__["kubeconfigs"] = kubeconfigs
        __props__.__dict__["name"] = name
        __props__.__dict__["open_id_connect_config"] = open_id_connect_config
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["pod_cidr"] = pod_cidr
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["service_cidr"] = service_cidr
        __props__.__dict__["service_dns_ip"] = service_dns_ip
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["upgrade_available"] = upgrade_available
        __props__.__dict__["version"] = version
        __props__.__dict__["wildcard_dns"] = wildcard_dns
        return KubernetesCluster(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="admissionPlugins")
    def admission_plugins(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of [admission plugins](https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/) to enable on the cluster.
        """
        return pulumi.get(self, "admission_plugins")

    @_builtins.property
    @pulumi.getter(name="apiserverCertSans")
    def apiserver_cert_sans(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Additional Subject Alternative Names for the Kubernetes API server certificate
        """
        return pulumi.get(self, "apiserver_cert_sans")

    @_builtins.property
    @pulumi.getter(name="apiserverUrl")
    def apiserver_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the Kubernetes API server.
        """
        return pulumi.get(self, "apiserver_url")

    @_builtins.property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> pulumi.Output['outputs.KubernetesClusterAutoUpgrade']:
        """
        The auto upgrade configuration.
        """
        return pulumi.get(self, "auto_upgrade")

    @_builtins.property
    @pulumi.getter(name="autoscalerConfig")
    def autoscaler_config(self) -> pulumi.Output['outputs.KubernetesClusterAutoscalerConfig']:
        """
        The configuration options for the [Kubernetes cluster autoscaler](https://github.com/kubernetes/autoscaler/tree/master/cluster-autoscaler).
        """
        return pulumi.get(self, "autoscaler_config")

    @_builtins.property
    @pulumi.getter
    def cni(self) -> pulumi.Output[_builtins.str]:
        """
        The Container Network Interface (CNI) for the Kubernetes cluster.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "cni")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The creation date of the cluster.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="deleteAdditionalResources")
    def delete_additional_resources(self) -> pulumi.Output[_builtins.bool]:
        """
        Delete additional resources like block volumes, load-balancers and the cluster's private network (if empty) that were created in Kubernetes on cluster deletion.
        > **Important:** Setting this field to `true` means that you will lose all your cluster data and network configuration when you delete your cluster.
        If you prefer keeping it, you should instead set it as `false`.
        """
        return pulumi.get(self, "delete_additional_resources")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A description for the Kubernetes cluster.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="featureGates")
    def feature_gates(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of [feature gates](https://kubernetes.io/docs/reference/command-line-tools-reference/feature-gates/) to enable on the cluster.
        """
        return pulumi.get(self, "feature_gates")

    @_builtins.property
    @pulumi.getter
    def kubeconfigs(self) -> pulumi.Output[Sequence['outputs.KubernetesClusterKubeconfig']]:
        """
        The kubeconfig configuration file of the Kubernetes cluster
        """
        return pulumi.get(self, "kubeconfigs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name for the Kubernetes cluster.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="openIdConnectConfig")
    def open_id_connect_config(self) -> pulumi.Output['outputs.KubernetesClusterOpenIdConnectConfig']:
        """
        The OpenID Connect configuration of the cluster
        """
        return pulumi.get(self, "open_id_connect_config")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID the cluster is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="podCidr")
    def pod_cidr(self) -> pulumi.Output[_builtins.str]:
        """
        The subnet used for the Pod CIDR.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "pod_cidr")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the private network of the cluster.

        > **Important:** Changes to this field will recreate a new resource.

        > **Important:** Private Networks are now mandatory with Kapsule Clusters. If you have a legacy cluster (no `private_network_id` set),
        you can still set it now. In this case it will not destroy and recreate your cluster but migrate it to the Private Network.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="serviceCidr")
    def service_cidr(self) -> pulumi.Output[_builtins.str]:
        """
        The subnet used for the Service CIDR.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "service_cidr")

    @_builtins.property
    @pulumi.getter(name="serviceDnsIp")
    def service_dns_ip(self) -> pulumi.Output[_builtins.str]:
        """
        The IP used for the DNS Service. If unset, defaults to Service CIDR's network + 10.

        > **Important:** Changes to this field will recreate a new resource. However once it has been set to a custom value,
        unsetting it to go back to the default value will not have any effect.
        """
        return pulumi.get(self, "service_dns_ip")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the Kubernetes cluster.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The tags associated with the Kubernetes cluster.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of Kubernetes cluster. Possible values are:

        - for mutualized clusters: `kapsule` or `multicloud`

        - for dedicated Kapsule clusters: `kapsule-dedicated-4`, `kapsule-dedicated-8` or `kapsule-dedicated-16`.

        - for dedicated Kosmos clusters: `multicloud-dedicated-4`, `multicloud-dedicated-8` or `multicloud-dedicated-16`.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The last update date of the cluster.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="upgradeAvailable")
    def upgrade_available(self) -> pulumi.Output[_builtins.bool]:
        """
        Set to `true` if a newer Kubernetes version is available.
        """
        return pulumi.get(self, "upgrade_available")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        The version of the Kubernetes cluster.
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter(name="wildcardDns")
    def wildcard_dns(self) -> pulumi.Output[_builtins.str]:
        """
        The DNS wildcard that points to all ready nodes.
        """
        return pulumi.get(self, "wildcard_dns")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetConnectorResult',
    'AwaitableGetConnectorResult',
    'get_connector',
    'get_connector_output',
]

@pulumi.output_type
class GetConnectorResult:
    """
    A collection of values returned by getConnector.
    """
    def __init__(__self__, connector_id=None, created_at=None, id=None, name=None, organization_id=None, project_id=None, region=None, status=None, tags=None, target_vpc_id=None, updated_at=None, vpc_id=None):
        if connector_id and not isinstance(connector_id, str):
            raise TypeError("Expected argument 'connector_id' to be a str")
        pulumi.set(__self__, "connector_id", connector_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if target_vpc_id and not isinstance(target_vpc_id, str):
            raise TypeError("Expected argument 'target_vpc_id' to be a str")
        pulumi.set(__self__, "target_vpc_id", target_vpc_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "connector_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetVpcId")
    def target_vpc_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "target_vpc_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "vpc_id")


class AwaitableGetConnectorResult(GetConnectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectorResult(
            connector_id=self.connector_id,
            created_at=self.created_at,
            id=self.id,
            name=self.name,
            organization_id=self.organization_id,
            project_id=self.project_id,
            region=self.region,
            status=self.status,
            tags=self.tags,
            target_vpc_id=self.target_vpc_id,
            updated_at=self.updated_at,
            vpc_id=self.vpc_id)


def get_connector(connector_id: Optional[_builtins.str] = None,
                  name: Optional[_builtins.str] = None,
                  project_id: Optional[_builtins.str] = None,
                  region: Optional[_builtins.str] = None,
                  tags: Optional[Sequence[_builtins.str]] = None,
                  target_vpc_id: Optional[_builtins.str] = None,
                  vpc_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectorResult:
    """
    Gets information about a VPC connector.

    A VPC connector enables network connectivity between two VPCs, allowing resources in separate VPCs to communicate with each other.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a VPC connector by its ID
    by_id = scaleway.network.get_connector(connector_id="fr-par/11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a VPC connector by name
    by_name = scaleway.network.get_connector(name="my-vpc-connector")
    ```


    :param _builtins.str connector_id: The ID of the VPC connector. Conflicts with all filter arguments below.
           
           The following arguments can be used to look up a VPC connector via the list API. They all conflict with `connector_id`:
    :param _builtins.str name: The name to filter for.
    :param _builtins.str project_id: The ID of the Project to filter for.
    :param _builtins.str region: `region`) The region in which the connector exists.
    :param Sequence[_builtins.str] tags: List of tags to filter for.
    :param _builtins.str target_vpc_id: The target VPC ID to filter for.
    :param _builtins.str vpc_id: The source VPC ID to filter for.
    """
    __args__ = dict()
    __args__['connectorId'] = connector_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['tags'] = tags
    __args__['targetVpcId'] = target_vpc_id
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:network/getConnector:getConnector', __args__, opts=opts, typ=GetConnectorResult).value

    return AwaitableGetConnectorResult(
        connector_id=pulumi.get(__ret__, 'connector_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        target_vpc_id=pulumi.get(__ret__, 'target_vpc_id'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_connector_output(connector_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                         target_vpc_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         vpc_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectorResult]:
    """
    Gets information about a VPC connector.

    A VPC connector enables network connectivity between two VPCs, allowing resources in separate VPCs to communicate with each other.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a VPC connector by its ID
    by_id = scaleway.network.get_connector(connector_id="fr-par/11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a VPC connector by name
    by_name = scaleway.network.get_connector(name="my-vpc-connector")
    ```


    :param _builtins.str connector_id: The ID of the VPC connector. Conflicts with all filter arguments below.
           
           The following arguments can be used to look up a VPC connector via the list API. They all conflict with `connector_id`:
    :param _builtins.str name: The name to filter for.
    :param _builtins.str project_id: The ID of the Project to filter for.
    :param _builtins.str region: `region`) The region in which the connector exists.
    :param Sequence[_builtins.str] tags: List of tags to filter for.
    :param _builtins.str target_vpc_id: The target VPC ID to filter for.
    :param _builtins.str vpc_id: The source VPC ID to filter for.
    """
    __args__ = dict()
    __args__['connectorId'] = connector_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['tags'] = tags
    __args__['targetVpcId'] = target_vpc_id
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:network/getConnector:getConnector', __args__, opts=opts, typ=GetConnectorResult)
    return __ret__.apply(lambda __response__: GetConnectorResult(
        connector_id=pulumi.get(__response__, 'connector_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        target_vpc_id=pulumi.get(__response__, 'target_vpc_id'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AclArgs', 'Acl']

@pulumi.input_type
class AclArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 acl_rules: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]]] = None,
                 no_ip_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Acl resource.
        :param pulumi.Input[_builtins.str] cluster_id: UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.
               
               > **Important:** Updates to `cluster_id` will recreate the ACL.
        :param pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]] acl_rules: A list of ACLs (structure is described below)
               
               > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        :param pulumi.Input[_builtins.bool] no_ip_allowed: If set to true, no IP will be allowed and the cluster will be in full-isolation.
               
               > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the ACL rule should be created.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if acl_rules is not None:
            pulumi.set(__self__, "acl_rules", acl_rules)
        if no_ip_allowed is not None:
            pulumi.set(__self__, "no_ip_allowed", no_ip_allowed)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.

        > **Important:** Updates to `cluster_id` will recreate the ACL.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="aclRules")
    def acl_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]]]:
        """
        A list of ACLs (structure is described below)

        > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        """
        return pulumi.get(self, "acl_rules")

    @acl_rules.setter
    def acl_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]]]):
        pulumi.set(self, "acl_rules", value)

    @_builtins.property
    @pulumi.getter(name="noIpAllowed")
    def no_ip_allowed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, no IP will be allowed and the cluster will be in full-isolation.

        > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        """
        return pulumi.get(self, "no_ip_allowed")

    @no_ip_allowed.setter
    def no_ip_allowed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "no_ip_allowed", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the ACL rule should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _AclState:
    def __init__(__self__, *,
                 acl_rules: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 no_ip_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Acl resources.
        :param pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]] acl_rules: A list of ACLs (structure is described below)
               
               > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        :param pulumi.Input[_builtins.str] cluster_id: UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.
               
               > **Important:** Updates to `cluster_id` will recreate the ACL.
        :param pulumi.Input[_builtins.bool] no_ip_allowed: If set to true, no IP will be allowed and the cluster will be in full-isolation.
               
               > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the ACL rule should be created.
        """
        if acl_rules is not None:
            pulumi.set(__self__, "acl_rules", acl_rules)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if no_ip_allowed is not None:
            pulumi.set(__self__, "no_ip_allowed", no_ip_allowed)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="aclRules")
    def acl_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]]]:
        """
        A list of ACLs (structure is described below)

        > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        """
        return pulumi.get(self, "acl_rules")

    @acl_rules.setter
    def acl_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclRuleArgs']]]]):
        pulumi.set(self, "acl_rules", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.

        > **Important:** Updates to `cluster_id` will recreate the ACL.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="noIpAllowed")
    def no_ip_allowed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, no IP will be allowed and the cluster will be in full-isolation.

        > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        """
        return pulumi.get(self, "no_ip_allowed")

    @no_ip_allowed.setter
    def no_ip_allowed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "no_ip_allowed", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the ACL rule should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("scaleway:kubernetes/acl:Acl")
class Acl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclAclRuleArgs', 'AclAclRuleArgsDict']]]]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 no_ip_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # Basic ACL usage
        acl_basic = scaleway.network.PrivateNetwork("acl_basic")
        acl_basic_cluster = scaleway.kubernetes.Cluster("acl_basic",
            name="acl-basic",
            version="1.32.2",
            cni="cilium",
            delete_additional_resources=True,
            private_network_id=acl_basic.id)
        acl_basic_acl = scaleway.kubernetes.Acl("acl_basic",
            cluster_id=acl_basic_cluster.id,
            acl_rules=[
                {
                    "ip": "1.2.3.4/32",
                    "description": "Allow 1.2.3.4",
                },
                {
                    "scaleway_ranges": True,
                    "description": "Allow all Scaleway ranges",
                },
            ])
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # Full isolation example
        acl_basic = scaleway.network.PrivateNetwork("acl_basic")
        acl_basic_cluster = scaleway.kubernetes.Cluster("acl_basic",
            name="acl-basic",
            version="1.32.2",
            cni="cilium",
            delete_additional_resources=True,
            private_network_id=acl_basic.id)
        acl_basic_acl = scaleway.kubernetes.Acl("acl_basic",
            cluster_id=acl_basic_cluster.id,
            no_ip_allowed=True)
        ```

        ## Import

        Kubernetes ACLs can be imported using the `{region}/{cluster-id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:kubernetes/acl:Acl acl01 fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AclAclRuleArgs', 'AclAclRuleArgsDict']]]] acl_rules: A list of ACLs (structure is described below)
               
               > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        :param pulumi.Input[_builtins.str] cluster_id: UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.
               
               > **Important:** Updates to `cluster_id` will recreate the ACL.
        :param pulumi.Input[_builtins.bool] no_ip_allowed: If set to true, no IP will be allowed and the cluster will be in full-isolation.
               
               > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the ACL rule should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # Basic ACL usage
        acl_basic = scaleway.network.PrivateNetwork("acl_basic")
        acl_basic_cluster = scaleway.kubernetes.Cluster("acl_basic",
            name="acl-basic",
            version="1.32.2",
            cni="cilium",
            delete_additional_resources=True,
            private_network_id=acl_basic.id)
        acl_basic_acl = scaleway.kubernetes.Acl("acl_basic",
            cluster_id=acl_basic_cluster.id,
            acl_rules=[
                {
                    "ip": "1.2.3.4/32",
                    "description": "Allow 1.2.3.4",
                },
                {
                    "scaleway_ranges": True,
                    "description": "Allow all Scaleway ranges",
                },
            ])
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        # Full isolation example
        acl_basic = scaleway.network.PrivateNetwork("acl_basic")
        acl_basic_cluster = scaleway.kubernetes.Cluster("acl_basic",
            name="acl-basic",
            version="1.32.2",
            cni="cilium",
            delete_additional_resources=True,
            private_network_id=acl_basic.id)
        acl_basic_acl = scaleway.kubernetes.Acl("acl_basic",
            cluster_id=acl_basic_cluster.id,
            no_ip_allowed=True)
        ```

        ## Import

        Kubernetes ACLs can be imported using the `{region}/{cluster-id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:kubernetes/acl:Acl acl01 fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param AclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclAclRuleArgs', 'AclAclRuleArgsDict']]]]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 no_ip_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AclArgs.__new__(AclArgs)

            __props__.__dict__["acl_rules"] = acl_rules
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["no_ip_allowed"] = no_ip_allowed
            __props__.__dict__["region"] = region
        super(Acl, __self__).__init__(
            'scaleway:kubernetes/acl:Acl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclAclRuleArgs', 'AclAclRuleArgsDict']]]]] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            no_ip_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'Acl':
        """
        Get an existing Acl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AclAclRuleArgs', 'AclAclRuleArgsDict']]]] acl_rules: A list of ACLs (structure is described below)
               
               > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        :param pulumi.Input[_builtins.str] cluster_id: UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.
               
               > **Important:** Updates to `cluster_id` will recreate the ACL.
        :param pulumi.Input[_builtins.bool] no_ip_allowed: If set to true, no IP will be allowed and the cluster will be in full-isolation.
               
               > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the ACL rule should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AclState.__new__(_AclState)

        __props__.__dict__["acl_rules"] = acl_rules
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["no_ip_allowed"] = no_ip_allowed
        __props__.__dict__["region"] = region
        return Acl(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aclRules")
    def acl_rules(self) -> pulumi.Output[Optional[Sequence['outputs.AclAclRule']]]:
        """
        A list of ACLs (structure is described below)

        > **Important:** This block cannot be defined if the `no_ip_allowed` field is set to true.
        """
        return pulumi.get(self, "acl_rules")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        UUID of the cluster. The ID of the cluster is also the ID of the ACL resource, as there can only be one per cluster.

        > **Important:** Updates to `cluster_id` will recreate the ACL.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="noIpAllowed")
    def no_ip_allowed(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If set to true, no IP will be allowed and the cluster will be in full-isolation.

        > **Important:** This field cannot be set to true if the `acl_rules` block is defined.
        """
        return pulumi.get(self, "no_ip_allowed")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the ACL rule should be created.
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .backend_stage import *
from .cache_stage import *
from .dns_stage import *
from .get_backend_stage import *
from .get_cache_stage import *
from .get_dns_stage import *
from .get_pipeline import *
from .get_route_stage import *
from .get_tls_stage import *
from .get_waf_stage import *
from .head_stage import *
from .pipeline import *
from .plan import *
from .route_stage import *
from .tls_stage import *
from .waf_stage import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IamApiKeyArgs', 'IamApiKey']

@pulumi.input_type
class IamApiKeyArgs:
    def __init__(__self__, *,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IamApiKey resource.
        :param pulumi.Input[_builtins.str] application_id: ID of the application attached to the API key.
        :param pulumi.Input[_builtins.str] default_project_id: The default Project ID to use with Object Storage.
        :param pulumi.Input[_builtins.str] description: The description of the API key.
        :param pulumi.Input[_builtins.str] expires_at: The date and time of the expiration of the IAM API key. Please note that in case of any changes,
               the resource will be recreated.
        :param pulumi.Input[_builtins.str] user_id: ID of the user attached to the API key.
               > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if default_project_id is not None:
            pulumi.set(__self__, "default_project_id", default_project_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the application attached to the API key.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectId")
    def default_project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default Project ID to use with Object Storage.
        """
        return pulumi.get(self, "default_project_id")

    @default_project_id.setter
    def default_project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_project_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the API key.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the expiration of the IAM API key. Please note that in case of any changes,
        the resource will be recreated.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the user attached to the API key.
        > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _IamApiKeyState:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 editable: Optional[pulumi.Input[_builtins.bool]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IamApiKey resources.
        :param pulumi.Input[_builtins.str] access_key: The access key of the IAM API key.
        :param pulumi.Input[_builtins.str] application_id: ID of the application attached to the API key.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the IAM API key.
        :param pulumi.Input[_builtins.str] creation_ip: The IP Address of the device which created the API key.
        :param pulumi.Input[_builtins.str] default_project_id: The default Project ID to use with Object Storage.
        :param pulumi.Input[_builtins.str] description: The description of the API key.
        :param pulumi.Input[_builtins.bool] editable: Whether the IAM API key is editable.
        :param pulumi.Input[_builtins.str] expires_at: The date and time of the expiration of the IAM API key. Please note that in case of any changes,
               the resource will be recreated.
        :param pulumi.Input[_builtins.str] secret_key: The secret Key of the IAM API key.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the IAM API key.
        :param pulumi.Input[_builtins.str] user_id: ID of the user attached to the API key.
               > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if creation_ip is not None:
            pulumi.set(__self__, "creation_ip", creation_ip)
        if default_project_id is not None:
            pulumi.set(__self__, "default_project_id", default_project_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if editable is not None:
            pulumi.set(__self__, "editable", editable)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key of the IAM API key.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the application attached to the API key.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the IAM API key.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="creationIp")
    def creation_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP Address of the device which created the API key.
        """
        return pulumi.get(self, "creation_ip")

    @creation_ip.setter
    def creation_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creation_ip", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectId")
    def default_project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default Project ID to use with Object Storage.
        """
        return pulumi.get(self, "default_project_id")

    @default_project_id.setter
    def default_project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_project_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the API key.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def editable(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the IAM API key is editable.
        """
        return pulumi.get(self, "editable")

    @editable.setter
    def editable(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "editable", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the expiration of the IAM API key. Please note that in case of any changes,
        the resource will be recreated.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret Key of the IAM API key.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the IAM API key.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the user attached to the API key.
        > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


warnings.warn("""scaleway.index/iamapikey.IamApiKey has been deprecated in favor of scaleway.iam/apikey.ApiKey""", DeprecationWarning)


@pulumi.type_token("scaleway:index/iamApiKey:IamApiKey")
class IamApiKey(pulumi.CustomResource):
    warnings.warn("""scaleway.index/iamapikey.IamApiKey has been deprecated in favor of scaleway.iam/apikey.ApiKey""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway API Keys. For more information, refer to the [IAM API documentation](https://www.scaleway.com/en/developers/api/iam/#api-keys-3665ae).

        ## Example Usage

        ### With application

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ci_cd = scaleway.iam.Application("ci_cd", name="My application")
        main = scaleway.iam.ApiKey("main",
            application_id=main_scaleway_iam_application["id"],
            description="a description")
        ```

        ### With user

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.iam.User("main", email="test@test.com")
        main_api_key = scaleway.iam.ApiKey("main",
            user_id=main.id,
            description="a description")
        ```

        ### With expiration

        ```python
        import pulumi
        import pulumi_time as time
        import pulumiverse_scaleway as scaleway

        rotate_after_a_year = time.index.Rotating("rotate_after_a_year", rotation_years=1)
        main = scaleway.iam.ApiKey("main",
            application_id=main_scaleway_iam_application["id"],
            expires_at=rotate_after_a_year["rotationRfc3339"])
        ```

        ## Import

        Api keys can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/iamApiKey:IamApiKey main 11111111111111111111
        ```

        ~> **Warning**: While an `iam_api_key` can be imported, its `secret_key` is a secret that is not exposed. An imported API key will have `null` as its secret key.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_id: ID of the application attached to the API key.
        :param pulumi.Input[_builtins.str] default_project_id: The default Project ID to use with Object Storage.
        :param pulumi.Input[_builtins.str] description: The description of the API key.
        :param pulumi.Input[_builtins.str] expires_at: The date and time of the expiration of the IAM API key. Please note that in case of any changes,
               the resource will be recreated.
        :param pulumi.Input[_builtins.str] user_id: ID of the user attached to the API key.
               > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IamApiKeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway API Keys. For more information, refer to the [IAM API documentation](https://www.scaleway.com/en/developers/api/iam/#api-keys-3665ae).

        ## Example Usage

        ### With application

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ci_cd = scaleway.iam.Application("ci_cd", name="My application")
        main = scaleway.iam.ApiKey("main",
            application_id=main_scaleway_iam_application["id"],
            description="a description")
        ```

        ### With user

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.iam.User("main", email="test@test.com")
        main_api_key = scaleway.iam.ApiKey("main",
            user_id=main.id,
            description="a description")
        ```

        ### With expiration

        ```python
        import pulumi
        import pulumi_time as time
        import pulumiverse_scaleway as scaleway

        rotate_after_a_year = time.index.Rotating("rotate_after_a_year", rotation_years=1)
        main = scaleway.iam.ApiKey("main",
            application_id=main_scaleway_iam_application["id"],
            expires_at=rotate_after_a_year["rotationRfc3339"])
        ```

        ## Import

        Api keys can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/iamApiKey:IamApiKey main 11111111111111111111
        ```

        ~> **Warning**: While an `iam_api_key` can be imported, its `secret_key` is a secret that is not exposed. An imported API key will have `null` as its secret key.

        :param str resource_name: The name of the resource.
        :param IamApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IamApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""IamApiKey is deprecated: scaleway.index/iamapikey.IamApiKey has been deprecated in favor of scaleway.iam/apikey.ApiKey""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IamApiKeyArgs.__new__(IamApiKeyArgs)

            __props__.__dict__["application_id"] = application_id
            __props__.__dict__["default_project_id"] = default_project_id
            __props__.__dict__["description"] = description
            __props__.__dict__["expires_at"] = expires_at
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["access_key"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["creation_ip"] = None
            __props__.__dict__["editable"] = None
            __props__.__dict__["secret_key"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IamApiKey, __self__).__init__(
            'scaleway:index/iamApiKey:IamApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key: Optional[pulumi.Input[_builtins.str]] = None,
            application_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            creation_ip: Optional[pulumi.Input[_builtins.str]] = None,
            default_project_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            editable: Optional[pulumi.Input[_builtins.bool]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'IamApiKey':
        """
        Get an existing IamApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the IAM API key.
        :param pulumi.Input[_builtins.str] application_id: ID of the application attached to the API key.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the IAM API key.
        :param pulumi.Input[_builtins.str] creation_ip: The IP Address of the device which created the API key.
        :param pulumi.Input[_builtins.str] default_project_id: The default Project ID to use with Object Storage.
        :param pulumi.Input[_builtins.str] description: The description of the API key.
        :param pulumi.Input[_builtins.bool] editable: Whether the IAM API key is editable.
        :param pulumi.Input[_builtins.str] expires_at: The date and time of the expiration of the IAM API key. Please note that in case of any changes,
               the resource will be recreated.
        :param pulumi.Input[_builtins.str] secret_key: The secret Key of the IAM API key.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the IAM API key.
        :param pulumi.Input[_builtins.str] user_id: ID of the user attached to the API key.
               > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IamApiKeyState.__new__(_IamApiKeyState)

        __props__.__dict__["access_key"] = access_key
        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["creation_ip"] = creation_ip
        __props__.__dict__["default_project_id"] = default_project_id
        __props__.__dict__["description"] = description
        __props__.__dict__["editable"] = editable
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["user_id"] = user_id
        return IamApiKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[_builtins.str]:
        """
        The access key of the IAM API key.
        """
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of the application attached to the API key.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the IAM API key.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="creationIp")
    def creation_ip(self) -> pulumi.Output[_builtins.str]:
        """
        The IP Address of the device which created the API key.
        """
        return pulumi.get(self, "creation_ip")

    @_builtins.property
    @pulumi.getter(name="defaultProjectId")
    def default_project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The default Project ID to use with Object Storage.
        """
        return pulumi.get(self, "default_project_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the API key.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def editable(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the IAM API key is editable.
        """
        return pulumi.get(self, "editable")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The date and time of the expiration of the IAM API key. Please note that in case of any changes,
        the resource will be recreated.
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[_builtins.str]:
        """
        The secret Key of the IAM API key.
        """
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the IAM API key.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of the user attached to the API key.
        > **Note** You must specify at least one: `application_id` and/or `user_id`.
        """
        return pulumi.get(self, "user_id")

